@@ -6,9 +6,9 @@ from git import Repo
 import os
 import sys 
 from pydriller import Git
-from library import iterate_over_diffs
-from library import put_into_df
-from library import create_prompt
+from .library import iterate_over_diffs
+from .library import put_into_df
+from .library import create_prompt
 
 @click.command()
 @click.option('--count', default=1, help='Number of greetings.')
